@@ -32,7 +32,7 @@
 #ifndef SQUID_DISKIOMODULE_H
 #define SQUID_DISKIOMODULE_H
 
-#include "base/Vector.h"
+#include "Array.h"
 
 /* forward decls */
 
