@@ -380,47 +380,32 @@ StoreEntry::storeClientType() const
     return STORE_DISK_CLIENT;
 }
 
-StoreEntry::StoreEntry() :
-        mem_obj(NULL),
+StoreEntry::StoreEntry():
         hidden_mem_obj(NULL),
-        timestamp(-1),
-        lastref(-1),
-        expires(-1),
-        lastmod(-1),
-        swap_file_sz(0),
-        refcount(0),
-        flags(0),
-        swap_filen(-1),
-        swap_dirn(-1),
-        lock_count(0),
-        mem_status(NOT_IN_MEMORY),
-        ping_status(PING_NONE),
-        store_status(STORE_PENDING),
-        swap_status(SWAPOUT_NONE)
+        swap_file_sz(0)
 {
     debugs(20, 3, HERE << "new StoreEntry " << this);
+    mem_obj = NULL;
+
+    expires = lastmod = lastref = timestamp = -1;
+
+    swap_status = SWAPOUT_NONE;
+    swap_filen = -1;
+    swap_dirn = -1;
 }
 
-StoreEntry::StoreEntry(const char *aUrl, const char *aLogUrl) :
-        mem_obj(NULL),
+StoreEntry::StoreEntry(const char *aUrl, const char *aLogUrl):
         hidden_mem_obj(NULL),
-        timestamp(-1),
-        lastref(-1),
-        expires(-1),
-        lastmod(-1),
-        swap_file_sz(0),
-        refcount(0),
-        flags(0),
-        swap_filen(-1),
-        swap_dirn(-1),
-        lock_count(0),
-        mem_status(NOT_IN_MEMORY),
-        ping_status(PING_NONE),
-        store_status(STORE_PENDING),
-        swap_status(SWAPOUT_NONE)
+        swap_file_sz(0)
 {
     debugs(20, 3, HERE << "new StoreEntry " << this);
     mem_obj = new MemObject(aUrl, aLogUrl);
+
+    expires = lastmod = lastref = timestamp = -1;
+
+    swap_status = SWAPOUT_NONE;
+    swap_filen = -1;
+    swap_dirn = -1;
 }
 
 StoreEntry::~StoreEntry()
@@ -657,9 +642,9 @@ storeGetPublicByRequest(HttpRequest * req)
 {
     StoreEntry *e = storeGetPublicByRequestMethod(req, req->method);
 
-    if (e == NULL && req->method == Http::METHOD_HEAD)
+    if (e == NULL && req->method == METHOD_HEAD)
         /* We can generate a HEAD reply from a cached GET object */
-        e = storeGetPublicByRequestMethod(req, Http::METHOD_GET);
+        e = storeGetPublicByRequestMethod(req, METHOD_GET);
 
     return e;
 }
@@ -703,7 +688,7 @@ StoreEntry::setPrivateKey()
         mem_obj->id = getKeyCounter();
         newkey = storeKeyPrivate(mem_obj->url, mem_obj->method, mem_obj->id);
     } else {
-        newkey = storeKeyPrivate("JUNK", Http::METHOD_NONE, getKeyCounter());
+        newkey = storeKeyPrivate("JUNK", METHOD_NONE, getKeyCounter());
     }
 
     assert(hash_lookup(store_table, newkey) == NULL);
@@ -776,7 +761,7 @@ StoreEntry::setPublicKey()
             StoreEntry *pe = storeCreateEntry(mem_obj->url, mem_obj->log_url, request->flags, request->method);
             /* We are allowed to do this typecast */
             HttpReply *rep = new HttpReply;
-            rep->setHeaders(Http::scOkay, "Internal marker object", "x-squid-internal/vary", -1, -1, squid_curtime + 100000);
+            rep->setHeaders(HTTP_OK, "Internal marker object", "x-squid-internal/vary", 0, -1, squid_curtime + 100000);
             vary = mem_obj->getReply()->header.getList(HDR_VARY);
 
             if (vary.size()) {
@@ -999,7 +984,7 @@ StoreEntry::checkCachable()
 {
 #if CACHE_ALL_METHODS
 
-    if (mem_obj->method != Http::METHOD_GET) {
+    if (mem_obj->method != METHOD_GET) {
         debugs(20, 2, "StoreEntry::checkCachable: NO: non-GET method");
         ++store_check_cachable_hist.no.non_get;
     } else
@@ -1399,15 +1384,15 @@ StoreEntry::validLength() const
         return 1;
     }
 
-    if (mem_obj->method == Http::METHOD_HEAD) {
+    if (mem_obj->method == METHOD_HEAD) {
         debugs(20, 5, "storeEntryValidLength: HEAD request: " << getMD5Text());
         return 1;
     }
 
-    if (reply->sline.status() == Http::scNotModified)
+    if (reply->sline.status == HTTP_NOT_MODIFIED)
         return 1;
 
-    if (reply->sline.status() == Http::scNoContent)
+    if (reply->sline.status == HTTP_NO_CONTENT)
         return 1;
 
     diff = reply->hdr_sz + reply->content_length - objectLen();
@@ -1695,8 +1680,6 @@ StoreEntry::url() const
 void
 StoreEntry::createMemObject(const char *aUrl, const char *aLogUrl)
 {
-    debugs(20, 3, "A mem_obj create attempted using : " << aUrl);
-
     if (mem_obj)
         return;
 
@@ -1994,7 +1977,7 @@ StoreEntry::hasIfNoneMatchEtag(const HttpRequest &request) const
     const String reqETags = request.header.getList(HDR_IF_NONE_MATCH);
     // weak comparison is allowed only for HEAD or full-body GET requests
     const bool allowWeakMatch = !request.flags.isRanged &&
-                                (request.method == Http::METHOD_GET || request.method == Http::METHOD_HEAD);
+                                (request.method == METHOD_GET || request.method == METHOD_HEAD);
     return hasOneOfEtags(reqETags, allowWeakMatch);
 }
 
